@echo off
:: install script for RE V2.1.1.1 (V2 Fix Pack 1 - Interim Fix 1 (IF1))
:: 2006/01/20 kjb
::
:: IF1 file list:
::   readme_if1.txt
::   install_if1
::   bin\db2laa
::   bin\db2mm
::   bin\db2ox
::   lib\aryi18n.jar
::   lib\aryi18n.dll
::   lib\db2jni.dll
::   lib\recex.jar


:: MAIN

:: initialize variables
:: list of files for IF1:
set IF1_FILES="readme_if1.txt install_if1.cmd bin\db2la.exe bin\db2mm.exe bin\db2ox.exe lib\aryi18n.jar lib\aryi18n.dll lib\b2jni.dll lib\recex.jar"
:: expected version string for RE V2.1 FP1
set RE_VERSION_STRING_FP1=2005101500
:: expected version string for RE V2.1 FP1 IF1
set RE_VERSION_STRING_IF1=2006012000
set RE_VERSION_NAME_FP1=DB2 Recovery Expert V2.1.1 (Fix Pack 1)
set RE_VERSION_NAME_IF1=DB2 Recovery Expert V2.1.1.1 (Fix Pack 1 Interim Fix 1)
set IF1_BACKUP=rev2111_if1_%RE_VERSION_STRING_IF1%_backup
:: this file should always exist in RE V2.1
set RE_JARFILE=lib\recex.jar
:: this file only exists with RE V2.1 FP1 and later
set REV2FP1_FILE=lib\aryi18n.jar
:: name of RE GUI "about box" class file
:: set IF1_ABOUTBOX="com/rocketsoftware/recexui/AboutBox.class"

echo %RE_VERSION_NAME_IF1% installation script.

:: assume script is run from directory containing the files to be installed
set IF1_DIR="."
if not exist "%IF1_DIR%\%install_if1.cmd" goto if1notfound


:: parse arguments
set IF1_FORCE_ARG=0
set IF1_INSTALL_ARG=0
set IF1_UNINSTALL_ARG=0
set IF1_FORCE_ARG=0
set IF1_TARGET_DIR=
set IF1_DO_INSTALL=0
set SKIP_VERSION_CHECKS=0
set IGNORE_BACKUP_ERRORS=0

goto loop
:shiftloop
shift
:loop

:: test for expected args
:: strip any surrounding quotes
set arg=%~1

if "%arg%" == "-i" set IF1_INSTALL_ARG=1
if "%arg%" == "-i" goto shiftloop

if "%arg%" == "-u" set IF1_UNINSTALL_ARG=1
if "%arg%" == "-u" goto shiftloop

if "%arg%" == "-f" set IF1_FORCE_ARG=1
if "%arg%" == "-f" goto shiftloop

if "%arg%" == "-h" goto prtusage

if "%arg%" == "" goto doneargs
if not "%IF1_TARGET_DIR%" == "" goto extraarg
set IF1_TARGET_DIR=%arg%
goto shiftloop


:if1notfound
echo Error: The install script must be run from the directory
echo containing the Interim Fix files to be installed.
goto exit

:extraarg
echo Error: Unexpected parameter '%arg%'.
goto :prtusage

:argcomberror
echo Error: The -i and -u parameters cannot be specified together.
goto :prtusage

:missingarg
echo Error: Must specify either -i or -u parameter.
goto :prtusage

:noinstalldir
echo Error: The installation directory was not specified and the DB2TOOLS
echo environment variable is not set.  Please rerun the script and provide
echo the installation directory pathname.
goto exit

:dirnotfound
echo Error: Directory %IF1_TARGET_DIR% is not valid or cannot be found.
goto exit

:renotfound
echo Error: DB2 Recovery Expert V2.1 not found in the target directory.
goto exit

:refp1notfound
echo Error: %RE_VERSION_NAME_FP1% is not installed.
echo This Interim Fix can only be installed on top of %RE_VERSION_NAME_FP1%.
goto exit

:if1alreadyinstalled
echo Error: Interim Fix 1 is already installed.
goto exit

:if1notinstalled
echo Error: Interim Fix 1 is not currently installed.
goto exit

:backupdirerror
echo Error: Unable to create backup directory %IF1_BACKUP
echo to make a backup copy of the current DB2 Recovery Expert
echo files in the install directory.
goto exit

:backuperror
echo Error: Unable to make a backup copy of the current
echo DB2 Recovery Expert files in the install directory.
goto exit
	
:restoreerror
echo Error: Unable to restore the previously saved DB2 Recovery Expert files.
echo One or more files are missing.
echo To ensure the product is in a known state, uninstall the current version
echo of Recovery Expert, and install a fresh copy before proceeding to use
echo the product.
goto exit
	
:installerror
echo Error: It does not appear that Interim Fix 1 was installed correctly.
echo Please verify the contents of the installation directory and check the
echo product version identifier in the application Help/About box.
echo To ensure the product is in a known state, uninstall the current version
echo of Recovery Expert, and install a fresh copy before proceeding to use
echo the product.
goto exit

:prtusage

echo.
echo Usage:
echo    install_if1 -i [-f] [target_dir]
echo    install_if1 -u [target_dir]
echo.
echo Arguments:
echo    -f           force execution; ignore version checks and backup errors
echo    -i           install the Interim Fix files
echo    -u           uninstall the Interim Fix and restore previously-saved files
echo    target_dir   target directory where Recovery Expert is installed
echo.   
echo Description:
echo.
echo This script installs the files for DB2 Recovery Expert V2.1.1.1
echo Fix Pack 1 Interim Fix 1.  Run the script with the "-i" parameter
echo to install the Interim Fix files, or with "-u" to uninstall the files.
echo The Recovery Expert installation directory can be specified as a
echo script parameter.  If omitted, the script uses the DB2TOOLS environment
echo variable to locate the deafult install directory.
echo.
echo During installation, the current version of Recovery Expert is
echo checked and the script saves the currently installed files 
echo and copies the new files into place.  If necessary, the Interim Fix
echo files can be uninstalled later by using the "-u" parameter.
echo.
echo The -f parameter can be used to force installation by skipping the
echo version checking phase, and ignoring errors when saving backup copies
echo of the files to be overwritten.  Use of this option is not recommended.
echo.

goto exit


:doneargs

:: check for conflicting arguments, and set install/uninstall flag
set IF1_DO_INSTALL=1
if "%IF1_INSTALL_ARG%" == "1"  goto chkuninstall
if "%IF1_UNINSTALL_ARG%" == "0" goto missingarg
set IF1_DO_INSTALL=0
goto okargs

:chkuninstall
if "%IF1_UNINSTALL_ARG%" == "1" goto argcomberror

:okargs

:: check if target directory was specified; if not, try to use the 
:: DB2TOOLS environment variable.  check if target directory exists.
if not "%IF1_TARGET_DIR%" == "" goto chkdircontents
if "%DB2TOOLS%" == "" goto noinstalldir
set IF1_TARGET_DIR=%DB2TOOLS%\RecoveryExpert
echo Using DB2TOOLS environment variable to construct default install location.

:chkdircontents
echo Looking for DB2 Recovery Expert in directory %IF1_TARGET_DIR% ...

:: check if target dir exists
if not exist "%IF1_TARGET_DIR%" goto dirnotfound
echo Installation directory %IF1_TARGET_DIR% found.

:: define backup directory name in terms of the target directory
set IF1_BACKUP=%IF1_TARGET_DIR%\%IF1_BACKUP%

:: verify that install directory contains RE V2.1 FP1 or higher
if not exist "%IF1_TARGET_DIR%\%RE_JARFILE%" goto renotfound
if not exist "%IF1_TARGET_DIR%\%REV2FP1_FILE%" goto refp1notfound

if "%IF1_DO_INSTALL%" == "0" goto douninstall

:doinstall
echo Preparing to install files for Interim Fix 1 ...
:: version to install IF1 on top of
set RE_VERSION_STRING=%RE_VERSION_STRING_FP1%
set RE_VERSION_NAME=%RE_VERSION_NAME_FP1%

:: check the RE version stamp before installing; it should correspond to 
:: the expected version (not so easy to do in Windows-Land)
:: as a fallback, we'll look if the IF1 backup directory exists; if so,
:: then assume that IF1 is already installed.  if not, proceed.
if not exist "%IF1_BACKUP%" goto backup0
if "%IF1_FORCE_ARG%" == "0" goto if1alreadyinstalled

:backup0

:: make a backup copy of the existing files in bin & lib directories
echo Saving a copy of the current DB2 Recovery Expert files ...
if exist "%IF1_BACKUP%" goto backup1
mkdir "%IF1_BACKUP%"
if exist "%IF1_BACKUP%" goto backup1
if "%IF1_FORCE_ARG%" == "0" goto backupdirerror
goto skipbackup

:backup1
if exist "%IF1_BACKUP%\bin" goto backup2
mkdir "%IF1_BACKUP%\bin"
if exist "%IF1_BACKUP%\bin" goto backup2
if "%IF1_FORCE_ARG%" == "0" goto backuperror
goto skipbackup

:backup2
if exist "%IF1_BACKUP%\lib" goto backup3
mkdir "%IF1_BACKUP%\lib"
if exist "%IF1_BACKUP%\lib" goto backup3
if "%IF1_FORCE_ARG%" == "0" goto backuperror
goto skipbackup

:backup3
copy "%IF1_TARGET_DIR%"\bin\*.* "%IF1_BACKUP%"\bin /Y > @NULL
copy "%IF1_TARGET_DIR%"\lib\*.* "%IF1_BACKUP%"\lib /Y > @NULL

:: spot-test for success
if exist "%IF1_BACKUP%\%RE_JARFILE%" goto backup4
if "%IF1_FORCE_ARG%" == "0" goto backuperror
:skipbackup
echo Error: Unable to make a backup copy of the current
echo DB2 Recovery Expert files in the install directory.
echo Ignoring errors; the installation will continue ...

:backup4

:: copy the new files into the install directory tree
echo Copying new files into installation directory ...
copy readme_if1*.txt "%IF1_TARGET_DIR%" /Y
copy install_if1*.cmd "%IF1_TARGET_DIR%" /Y
copy bin\*.* "%IF1_TARGET_DIR%"\bin /Y
copy lib\*.* "%IF1_TARGET_DIR%"\lib /Y

:: spot-test for success
if not exist "%IF1_TARGET_DIR%\readme_if1.txt" goto installerror

:: report new version info
set RE_VERSION_STRING=%RE_VERSION_STRING_IF1%
set RE_VERSION_NAME=%RE_VERSION_NAME_IF1%
echo Success! %RE_VERSION_NAME% installed.
echo Updated version set to %RE_VERSION_STRING_%.

echo Installation complete.
goto exit


:douninstall
echo Preparing to uninstall Interim Fix 1 files ...
:: version to uninstall
set RE_VERSION_STRING=%RE_VERSION_STRING_IF1%
set RE_VERSION_NAME=%RE_VERSION_NAME_IF1%

:: check the RE version stamp before uninstalling; it should correspond to 
:: the expected version (not so easy to do in Windows-Land)
:: as a fallback, we'll look if the IF1 backup directory exists; if so,
:: then assume that IF1 is currently installed.  if not, give up.
if not exist "%IF1_BACKUP%" goto if1notinstalled

:: restore the backup copy of the RE files into bin & lib directories
echo Restoring the previous DB2 Recovery Expert files ...
if not exist "%IF1_BACKUP%\bin" goto restoreerror
if not exist "%IF1_BACKUP%\lib" goto restoreerror
if not exist "%IF1_BACKUP%\%RE_JARFILE%" goto restoreerror
copy "%IF1_BACKUP%"\bin\*.* "%IF1_TARGET_DIR%\bin" /Y > @NULL
copy "%IF1_BACKUP%"\lib\*.* "%IF1_TARGET_DIR%\lib" /Y > @NULL
:: remove the old backup files and directories
del /Q "%IF1_BACKUP%"\bin\*.*
del /Q "%IF1_BACKUP%"\lib\*.*
rmdir /S /Q "%IF1_BACKUP%"

:: report new version info
set RE_VERSION_STRING=%RE_VERSION_STRING_FP1%
set RE_VERSION_NAME=%RE_VERSION_NAME_FP1%
:: don't report the actual version info, since we're not sure what it is.
echo Success! The previous version of DB2 Recovery Expert has been restored.

echo Uninstallation complete.
goto exit


:: script exit point
:exit
